Data and configuration files
****************************

.. contents::
   :local:

Technology (:file:`water/technology.yaml`)
==========================================

.. literalinclude:: ../../message_ix_models/data/water/technology.yaml
   :language: yaml

Other sets (:file:`water/set.yaml`)
===================================

.. literalinclude:: ../../message_ix_models/data/water/set.yaml
   :language: yaml

Configuration (:file:`water/config.yaml`)
=============================================

.. literalinclude:: ../../message_ix_models/data/water/config.yaml
   :language: yaml
